@@ -430,6 +430,8 @@ class ReservedNames(object):
         ],
         'postgres': [
         ],
+        'sqlite': [
+        ],
         'mysql': [
             'KEY',
         ],
@@ -444,8 +446,6 @@ class ReservedNames(object):
             dbType = dictionary[DB_TYPE]
             if dbType in self.sqlKeywordLists:
                 self.reservedNames += self.sqlKeywordLists[dbType]
-            else:
-                self.reservedNames += self.sqlKeywordLists['default']
         return self.reservedNames
 
     getReservedNames = classmethod(getReservedNames)
@@ -638,6 +638,11 @@ class MetaMapperAttribute(MetaBase):
                 return IntCol(default=self.default)
             else:
                 return IntCol()
+        elif issubclass(self.dom.__class__, dm.dom.meta.Float):
+            if hasattr(self, 'default'):
+                return FloatCol(default=self.default)
+            else:
+                return FloatCol()
         elif issubclass(self.dom.__class__, dm.dom.meta.BLOB):
             if hasattr(self, 'default'):
                 return BLOBCol(default=self.default)
@@ -680,6 +685,11 @@ class MetaMapperAttribute(MetaBase):
                 return IntCol(default=self.default)
             else:
                 return IntCol()
+        elif issubclass(self.dom.__class__, dm.dom.meta.Float):
+            if hasattr(self, 'default'):
+                return FloatCol(default=self.default)
+            else:
+                return FloatCol()
         elif issubclass(self.dom.__class__, dm.dom.meta.BLOB):
             if hasattr(self, 'default'):
                 return BLOBCol(default=self.default)
