@@ -11,14 +11,9 @@ def suite():
 class TestSettings(unittest.TestCase):
 
     def test_main(self):
-        # stable actual values, check for correct value
-        self.failUnlessEqual(settings.TIME_ZONE, 'Europe/Paris')
-        
-        # unstable actual values, check for any value
+        self.failUnless(settings.TIME_ZONE)
         self.failUnless(settings.SECRET_KEY)
         self.failUnless(settings.TEMPLATE_DIRS)
-
-        # abstract settings, check for null value
         self.failUnlessEqual(settings.ROOT_URLCONF, '')
 
 class TestUrls(unittest.TestCase):
