@@ -30,6 +30,7 @@ class TestDomainModelDumper(TestCase):
         self.failUnlessEqual(dump['Action']['metaData']['name'], 'String')
         self.failUnless(dump['Action'][1])
         self.failUnlessEqual(dump['Action'][1]['name'], 'Create')
+        self.failUnlessEqual(dump['Person'][3]['fullname'], u'Levin \xf3'.encode('utf8'))
 
     def testDumpDataAsJson(self):
         self.failUnless(self.dumper.dumpDataAsJson())
@@ -69,12 +70,15 @@ class TestDomainModelLoader(TestCase):
         self.loader.loadDataAsJson("""{
             "Person": {
                 "metaData": {"name": "String"},
-                "%s": {"name": "migrated"},
-                "%s": {"name": "migrated2"}
+                "%s": {"name": "migrated", "fullname": "Unicode \xc3\xb3 Jeff"},
+                "%s": {"name": "migrated2", "dateCreated": "2005-12-31 18:30:00"}
             }
         }""" % (lastId+1, lastId+2))
         self.failUnless('migrated' in self.registry.persons)
+        self.failUnlessEqual(self.registry.persons['migrated'].fullname, "Unicode \xc3\xb3 Jeff".decode('utf8'))
         self.failUnless('migrated2' in self.registry.persons)
+        import mx.DateTime
+        self.failUnlessEqual(self.registry.persons['migrated2'].dateCreated, mx.DateTime.DateTime(2005,12,31,18,30,0))
         del(self.registry.persons['migrated'])
         del(self.registry.persons['migrated2'])
         self.failIf('migrated' in self.registry.persons)
@@ -179,7 +183,7 @@ class TestDomainModelMigrator(DomainModelMigratorTestCase):
         'Place': {
             2: {
                 'id': 2,
-                'title': 'Hill Top',
+                'title': 'Hill Top \xc3\xb3',
                 'location': 'GR465798',
                 'image': '',
                 'dateDiscovered': '2007-03-04 00:00:00',
@@ -208,7 +212,7 @@ class TestDomainModelMigrator(DomainModelMigratorTestCase):
         self.failUnless('officialname' in place, place)
         self.failUnless('gridref' in place, place)
         self.failUnless('dateDiscovered' in place, place)
-        self.failUnlessEqual(place['officialname'], 'Hill Top')
+        self.failUnlessEqual(place['officialname'], 'Hill Top \xc3\xb3')
         self.failUnlessEqual(place['gridref'], 'GR465798')
         self.failUnlessEqual(place['dateDiscovered'], '2007-03-04')
 
