@@ -637,14 +637,19 @@ class SessionView(ControlledAccessView):
         return self.context
 
     def setContext(self, **kwds):
-        domainName = self.dictionary['domain_name']
-        if self.dictionary['www.port_http'] != '80':
-            systemServicePort = self.dictionary['www.port_http']
+        domainName = self.dictionary[DOMAIN_NAME]
+        if self.dictionary[HTTP_PORT] != '80':
+            systemServicePort = self.dictionary[HTTP_PORT]
             systemServiceSocket = domainName +":"+ systemServicePort
         else:
             systemServiceSocket = domainName
             
-        mediaHost = self.dictionary[MEDIA_HOST] 
+        mediaHost = self.dictionary[MEDIA_HOST]
+        if not mediaHost:
+            try:
+                mediaHost = self.request.META['SERVER_NAME']
+            except:
+                mediaHost = domainName
         if self.dictionary[MEDIA_PORT] != '80':
             mediaPort = self.dictionary[MEDIA_PORT]
             systemMediaSocket = mediaHost +":"+ mediaPort
