@@ -411,8 +411,8 @@ class DomainObjectManipulator(BaseManipulator):
                     )
         if field:
             field.metaAttr = metaAttr
-            field.field_title = metaAttr.calcTitle()
             field.field_comment = metaAttr.comment
+            field.field_title = metaAttr.calcTitle()
             if webkitName == 'django' and webkitVersion == '1.0':
                 field.field_name = metaAttr.name
                 self.fields[metaAttr.name] = field
@@ -499,6 +499,10 @@ class DomainObjectManipulator(BaseManipulator):
                 if metaAttr.name in self.fieldNames:
                     if metaAttr.name in data:
                         metaAttrs[metaAttr.name] = metaAttr
+                    elif metaAttr.isValueRef and metaAttr.isBoolean:
+                    # Must include Boolean attributes, need to find out what depends on excluding unsubmitted values.
+                    # Todo: Test we can set Boolean attributes to false values through the registry views.
+                        metaAttrs[metaAttr.name] = metaAttr
         return metaAttrs
 
     # Todo: Rename MultiValueDict as PresentationObject.
@@ -509,11 +513,11 @@ class DomainObjectManipulator(BaseManipulator):
                 domValue = metaAttr.makeValueFromMultiValueDict(multiValueDict)
                 domValues[attrName] = domValue
             except Exception, inst:
-                msg = "Can't make '%s' value from multi-value dict: %s" % (
-                    attrName, multiValueDict
+                msg = "Can't make '%s' value from multi-value dict: %s: %s" % (
+                    attrName, multiValueDict, inst
                 )
                 self.logger.error(msg)
-                raise
+                raise Exception, msg
         return domValues
 
     def update(self, data):
@@ -540,6 +544,10 @@ class DomainObjectManipulator(BaseManipulator):
     def setAttributesFromMultiValueDict(self, domainObject, multiValueDict):
         fieldedAttrs = self.getFieldedMetaAttrs()
         attrValues = self.presentationToDomainValues(multiValueDict, fieldedAttrs)
+        msg = "Updating fielded attributes '%s' with domain values '%s' derived from presentation values '%s'." % (
+            str(fieldedAttrs.keys()), str(attrValues), str(multiValueDict)
+        )
+        self.logger.debug(msg)
         for attrName in fieldedAttrs:
             metaAttr = fieldedAttrs[attrName]
             attrValue = attrValues[attrName]
@@ -635,9 +643,10 @@ class FormWrapper(object):
     def wrapManipulatorFields(self):
         wrappedFields = []
         if webkitName == 'django' and webkitVersion == '1.0':
-            for fieldName in self.manipulator.fields.keys():
+            #for fieldName in self.manipulator.fields.keys():
+            for fieldName in self.manipulator.fieldNames:
                 boundField = self.manipulator.__getitem__(fieldName)
-                wrappedField = self.wrapField(fieldName, boundField)
+                wrappedField = self.wrapBoundField(fieldName, boundField)
                 wrappedFields.append(wrappedField)
         elif webkitName == 'django' and webkitVersion == '0.96':
             for field in self.manipulator.fields:
@@ -670,7 +679,7 @@ class FormWrapper(object):
 
         return wrappedFields
 
-    def wrapField(self, fieldName, field): 
+    def wrapBoundField(self, fieldName, field): 
         field.field_name = fieldName
         data = self.data.get(fieldName, None)
         if data is None:
@@ -682,7 +691,7 @@ class FormWrapper(object):
         if webkitName == 'django' and webkitVersion == '1.0':
             fieldName = key
             boundField = self.manipulator.__getitem__(fieldName)
-            return self.wrapField(fieldName, boundField)
+            return self.wrapBoundField(fieldName, boundField)
         elif webkitName == 'django' and webkitVersion == '0.96':
             for field in self.manipulator.fields:
                 if field.field_name == key:
@@ -707,18 +716,31 @@ class FormFieldWrapper(object):
     "A bridge between the template system and an individual form field. Used by FormWrapper."
     
     def __init__(self, formfield, data, error_list):
-        #if formfield.field_name == 'svn':
-        #    raise Exception, repr(data)
-        self.formfield, self.data, self.error_list = formfield, data, error_list
+        self.formfield = formfield
+        self.data = data
+        self.error_list = error_list
         self.field_name = self.formfield.field_name
         if webkitName == 'django' and webkitVersion == '1.0':
             field = self.formfield.field
+            if hasattr(field, 'required'):
+                self.field_required = field.required
+            if hasattr(field, 'field_title'):
+                self.field_title = field.field_title
+            if hasattr(field, 'label'):
+                self.field_title = field.label
+            if hasattr(field, 'field_comment'):
+                self.field_comment = field.field_comment
+            elif hasattr(field, 'help_text'):
+                self.field_comment = field.help_text
         elif webkitName == 'django' and webkitVersion == '0.96':
             field = self.formfield
-        if hasattr(field, 'field_title'):
-            self.field_title = field.field_title
-        if hasattr(field, 'field_comment'):
-            self.field_comment = field.field_comment
+            if hasattr(field, 'is_required'):
+                self.field_required = field.is_required
+            if hasattr(field, 'field_title'):
+                self.field_title = field.field_title
+            if hasattr(field, 'field_comment'):
+                self.field_comment = field.field_comment
+        #self.field_required = True
         self.error = self.makeErrorMessage()
 
     def makeErrorMessage(self):
