@@ -3,6 +3,7 @@ import dm.view.manipulatortest
 import dm.view.basetest
 import dm.view.admintest
 import dm.view.registrytest
+import dm.view.rpctest
 
 def suite():
     suites = [
@@ -10,6 +11,7 @@ def suite():
         dm.view.basetest.suite(),
         dm.view.admintest.suite(),
         dm.view.registrytest.suite(),
+        dm.view.rpctest.suite(),
     ]
     return unittest.TestSuite(suites)
 
